use std::fs::{copy, create_dir, metadata, set_permissions, Permissions};
use std::path::PathBuf;

use crate::error::*;

pub fn get_perms(path: &PathBuf) -> MkrootResult<Permissions> {
	match metadata(path) {
		Ok(meta) => Ok(meta.permissions()),
		Err(e) => Err(MkrootError::from(format!(
			"Error retrieving metadata {}: {}",
			path.display(),
			e
		))),
	}
}

pub fn set_perms(path: &PathBuf, perms: Permissions) -> MkrootResult<()> {
	if let Err(e) = set_permissions(path, perms) {
		return Err(MkrootError::from(format!(
			"Error setting permissions {}: {}",
			path.display(),
			e
		)));
	}

	Ok(())
}

pub fn mkdir(dir: &PathBuf) -> MkrootResult<()> {
	if let Err(e) = create_dir(&dir) {
		return Err(MkrootError::from(format!(
			"Error creating directory {}: {}",
			&dir.display(),
			e
		)));
	}

	Ok(())
}

pub fn copy_file(src: &PathBuf, dst: &PathBuf) -> MkrootResult<()> {
	if let Err(e) = copy(&src, &dst) {
		return Err(MkrootError::from(format!(
			"Error copying file from {} to {}: {}",
			&src.display(),
			&dst.display(),
			e
		)));
	}

	Ok(())
}
